# rostpy

[![Documentation Status][rtd-badge]][rtd-link]
[![Code style: black][black-badge]][black-link]

[![PyPI version][pypi-version]][pypi-link]
[![PyPI platforms][pypi-platforms]][pypi-link]





[black-badge]:              https://img.shields.io/badge/code%20style-black-000000.svg
[black-link]:               https://github.com/psf/black
[pypi-link]:                https://pypi.org/project/rostpy/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/rostpy
[pypi-version]:             https://badge.fury.io/py/rostpy.svg
[rtd-badge]:                https://readthedocs.org/projects/rostpy/badge/?version=latest
[rtd-link]:                 https://rostpy.readthedocs.io/en/latest/?badge=latest
